#!/bin/sh
#
# chkconfig: S 39 0
#
# Recovers data from the flash memory, must be executed after kopts.sh

MPT=/mnt/data
HTPASSWD=/etc/spinetix/htpasswd
HTCONFD=/etc/apache/conf.d
NETCONF=/etc/spinetix/network
SPXCONF=/etc/spinetix/spxsafeconf

getfiles() {
    mtdblock="$(sed -e '/"failsafe-data"$/{s,\([0-9]\+\):.*,block\1,;p};d' \
        /proc/mtd)"
    mkdir -p "$MPT"
    mount -t cramfs -r /dev/"$mtdblock" "$MPT"
    if [ $? -ne 0 ]; then
	echo 'Could not get failsafe data files'
	return 1
    fi
    cd "$MPT"

    # Here copy each file to its destination place
    # as well as any conditional processing

    # Web interface access protection

    if [ -f "$MPT"/htpasswd ]; then
	cp -f "$MPT"/htpasswd "$HTPASSWD"
	if grep -q '^admin:' "$HTPASSWD"; then
	    mv -f "$HTCONFD"/00-auth.conf.off "$HTCONFD"/00-auth.conf
	fi
    fi

    # Network hostname

    if [ -f "$MPT"/hostname ]; then
	cp -f "$MPT"/hostname /etc/hostname
    fi

    # Network settings

    if [ -f "$MPT"/network ]; then
	cp -f "$MPT"/network "$NETCONF"
	if [ -s "$NETCONF" ]; then
	    "$SPXCONF" network
	fi
    fi

    # Do not copy files after this point

    cd /
    umount "$MPT"
    return 0
}

case "$1" in
    start|restart)
    getfiles
    ;;
    stop|reload|force-reload)
    ;;
esac
