#!/bin/bash
#
#  Copyright 2006 by Texas Instruments Incorporated.
#
#  Modifications (C) 2007-2008 SpinetiX S.A.
#  
#  All rights reserved. Property of Texas Instruments Incorporated.
#  Restricted rights to use, duplicate or disclose this code are
#  granted through contract.
#  
#

# Modules are loaded from the current directory if present (using insmod),
# otherwise they are loaded from the collection of system modules by modprobe.
#
# A failure in loading a module or creating the device node immediately fails
# this script.

function loadmodule
{
    local modname="$1"
    shift
    if [ -f "$modname".ko ]; then
        insmod "$modname".ko "$@"
    else
        modprobe "$modname" "$@"
    fi
}

#
# Functions to check and set the amount of maximum kernel memory
#
kernel_mem="178176k"

function check_kmem
{
    local mem="$(fw_printenv -n mem 2>/dev/null)"
    if [ "$mem" != "$kernel_mem" ]; then
	if [ "$1" != "-s" ]; then
	    echo "incorrect kernel memory: '$mem' instead of '$kernel_mem'" >&2
	fi
	return 1
    else
	return 0
    fi
}

function set_kmem
{
    local ret

    fw_setenv mem "$kernel_mem"
    ret=$?
    if [ "$ret" -eq 0 ]; then
	echo "Successfully set kernel memory to '$kernel_mem'"
    else
	echo "Failed setting kernel memory to '$kernel_mem'" >&2
    fi
    return $ret
}

function upgrade_kmem
{
    check_kmem -s || set_kmem
}

function check_kargs
{
    local args="$(fw_printenv -n mainexargs 2>/dev/null)"
    if [ -n "$args" ]; then
	if [ "$1" != "-s" ]; then
	    echo "incorrect kernel extra arguments: '$args' instead of nothing" >&2
	fi
	return 1
    else
	return 0
    fi
}

function set_kargs
{
    local ret

    fw_setenv mainexargs
    ret=$?
    if [ "$ret" -eq 0 ]; then
	echo "Successfully unset kernel extra arguments"
    else
	echo "Failed unsetting kernel extra arguments" >&2
    fi
    return $ret
}

function upgrade_kargs
{
    check_kargs -s || set_kargs
}

# Handle request for upgrading kernel memory and extra arguments

# WARNING: this is referred also from the recovery system when installing a
# new firmware image, so do not change the name of the argument or its
# meaning, nor the location of this script. It must be executable from
# the recovery system (i.e. no funky dependencies).

if [ "$1" == "upgrade" ]; then
    upgrade_kmem && upgrade_kargs
    exit
fi

# Check that the correct kernel memory is set, if not we modify it so
# that next boot takes it.
if ! check_kmem; then
    echo "setting correct value for future boots" >&2
    set_kmem >&2
fi

# insert cmemk, tell it to occupy physical 174MB-176MB, create
# just one 2 MB buffer for the command pipe, no other
# physically contiguous buffers are required.
# WARNING: adapt the value of kernel_mem above if placement changes
loadmodule cmemk \
    phys_start=0x8AE00000 phys_end=0x8b000000 \
    pools=1x2097152 max_shared=20971520 \
    || exit

# insert dsplinkk
loadmodule dsplinkk || exit

# make /dev/dsplink
rm -f /dev/dsplink
mknod /dev/dsplink c `awk "\\$2==\"dsplink\" {print \\$1}" /proc/devices` 0

#
#  @(#) codec_engine_1_02 1,0,0,147 7-14-2006 ce-d14
#

