<?php

# This file should contain all the general helper functions,
# it is included by prolog.php, but can also be included before
# if necessary. Note that prolog.php will not include it a
# second time if it was already included.

function ip_check($ip) {
      $vals=explode (".",$ip);
      if (count($vals)!=4) return false;
      foreach ($vals as $val) {
	   if (!is_numeric($val) || $val<0 || $val>255) return false;
      }
      if ($vals[0]==0) return false;
      if ($vals[0]==255 && $vals[1]==255 && $vals[2]==255 && $vals[3]==255) return false;
      
      return true;
}
function netmask_check($ip) {
      $vals=explode (".",$ip);
      if (count($vals)!=4) return false;
      $mustbezero=false;
      foreach ($vals as $val) {
	   if (!is_numeric($val) || $val<0 || $val>255) return false;
	   if ($mustbezero && $val!=0) return false;
	   if (!$mustbezero && $val!=255 && $val!=254 && $val!=252 && $val!=248 && $val!=240 && $val!=224 && $val!=192 && $val!=128 && $val!=0) return false;
	   if ($val!=255) $mustbezero=true;
      }
      if ($vals[0]==0) return false;
      if ($vals[0]==255 && $vals[1]==255 && $vals[2]==255 && $vals[3]==255) return false;
      return true;
}
function ipconf_check($adr, $msk, $gateway) {
	$a=ip2long($adr);
	$m=ip2long($msk);
	$g=ip2long($gateway);

	if ( ($a & $m) == $a ) return false;
	if ( ($a & $m) != ($g & $m) ) return false;
	if ( $a == $g ) return false;
	return true;
}

function has_shell_metachars($str) {
     return preg_match('/[][\\$*?|&;()<>"\*\?\'\\\\]/', $str);
}

function save_file($name, $data, $rootonly=false) {
	if ($data=="") return ;
	
	$fname=tempnam(dirname($name), basename($name));
	if (file_put_contents($fname,$data)<=0){
		echo "<h3>Cannot save settings</h3> File: ($name).<br/>Data: $data\n";
		return false;
	}else{
		if (!$rootonly)
			chmod($fname, 0644);
		exec('sync');
		if (rename($fname, $name)){
			exec('sync');
			return true;
		} else {
			unlink($fname);
			echo "<h3>Cannot save settings</h3> File: ($name).<br/>Data: $data\n";
			return false;
		}
		
	}
}
function save_symlink($target, $link) {
    if ( ! symlink($target, $link) ) {
	unlink($link);
	if ( ! symlink($target, $link) ) {
	    echo "<h3>Cannot save settings</h3> File: $link as symlink to ($target)\n";
	    return false;
	}
    }
    exec('sync');
    return true;
}

function reconfig_player() {
     $pid = trim(file_get_contents('/var/run/raperca.pid'));
     posix_kill($pid, SIGHUP);
}

function shutdown($msg = null, $forcereboot=false) {
	global $installationmode;
	if ($installationmode && !$forcereboot){
		if ( $msg == null ) $msg="unknown reason";
		if (file_exists("/var/run/reboot-pending"))
			$pending = file_get_contents("/var/run/reboot-pending");
		else $pending="";
		$pending = $pending.$msg."\n";
		file_put_contents("/var/run/reboot-pending", $pending);
		echo "<h3>Change saved.</h3><p>Adding the following to the pending change list<ul>";
		echo "<li>$msg</li></ul>";
		echo "\nMake sure you restart the HMP100 to activate it.</p>\n";
		syslog(LOG_NOTICE, "configuration change in installation mode:" . $msg);
	} else {
		echo "<h3>Device is restarting.</h3>\nThere will be no indication that the HMP100 is back online. Please wait for 2 minutes before using the http interface again.\n";
		if ($installationmode)
			syslog(LOG_NOTICE, "installation mode shutdown" . ($msg ? (": " . $msg) : ''));
		else
			syslog(LOG_NOTICE, "user initiated shutdown" . ($msg ? (": " . $msg) : ''));
		exec('/sbin/shutdown -r now');
	}
}

?>
